% The program is for the TNF-a ~ NF-kB model published in the paper 'Huang,Z.,Senocak , F., Jayaraman, A., and Hahn, J. , BMC systems biology, 2008, 2:64'
% Please refer to this paper for the details of the meaning for the parameters and states in the model. 
% To whom correspondence should be addressed. Juergen Hahn, Tel.: (979) 845 3568, Fax: (979) 845 6446, e-mail: hahn@tamu.edu

clear;
clc;
global k1p k15p k2p k16p k3p k17p k4p k18p k5p k19p k6p k20p k7p k21p k8p k22p k9p k23p k10p k24p k11p k25p k12p k26p k13p k14p k28p p 
global kv AB c1 c2 c3 c4 c5 k1 k2 k3 kprod kdeg a2 a1 a3 t1 t2 AA c1a c2a c3a c4a c5a c6a 
global i1 e2a i1a e1a c1c c2c c3c u
 
%% Values of the parameters in the model
%values cited from Lipniacki's paper
kv = 5;                                 
AB = 1;                            
c1 = AB*0.00005/100;     
c2 = AB*0.000000;        
c3 = 0.0104;             %estimated by experimental data
c4 = 0.005*100;          
c5 = 0.0003;             
k1 = 0.0025;             
k2 = 0.1;                
k3 = 0.0015;            
kprod = 0.000025;  
kdeg = 0.000125;
a2 = 0.2;                
a1 = 0.5;                
a3 = 1.;                 
t1 = 0.1;               
t2 = 0.1;                
AA = 1;                 
c1a = AA*0.00005/100;   
c2a = AA*0.000000;      
c3a = 0.0004;           
c4a = 0.005*100;        
c5a = 0.0001;          
c6a = 0.00002;          
i1 = 0.0025;            
e2a = 0.01;             
i1a = 0.001;           
e1a = 0.0005;            
c1c = 0.00005/100;      
c2c = 0.;               
c3c = 0.0004;           
TR = 1; %for continuous stimulation of TNF-a  

%values cited from Sirovic's paper
k1p = 0.0740; %estimated by experimental data. 
k15p = 0.185;
k2p = 0.00125;
k16p = 0.00125;
k3p = 0.185;
k17p = 0.37;
k4p = 0.00125;
k18p =  0.5;
k5p =  0.185;
k19p =  0.2;
k6p = 0.00125;
k20p = 0.1;
k7p = 0.185;
k21p = 0.1;
k8p = 0.00125;
k22p = 0.06;
k9p = 0.185;
k23p = 100;
k10p = 0.00125;
k24p = 0.185;
k11p = 0.37; 
k25p = 0.00125;
k12p = 0.014 ;
k26p = 0.37;
k13p = 0.00125;
k14p = 0.37;
k28p = 0.5;
p = 1.75;
factor=2.5000; %estimated by experimental data. 

%% Initial values of the states in the model
y0 = zeros(1,37);
y0(1) = 0.100;
y0(3) = 0.150;
y0(5) = 0.100;
y0(7) = 0.100;
y0(9) = 0.200; %Sirovic value is 0.1 
y0(15) = 0.0003;
y0(16) = 0.0023;
y0(17) = 0.0048;
y0(19) = 0.0025;
y0(20) = 0.0034;
y0(22) = 0.0592; 
y0(23) = 0.0001;
y0(25) = 0.100;
y0(28) = 0.08;
y0(31) = 0.2;
y0(36) =  0.8;

%% Simulation based on the model
tspan = [0,3600*15];     
u  = 10/17/10^3;% '10' means TNF-a = 10 ng/ml. The molecule weight of TNF-a is 17 kDa. The unit ng/ml can be converted to M by dividing by 1710^3 
                
[T,Y] = ode23tb(@model_TNFa,tspan,y0,[],TR); 
NFKB = Y(:,16)*1000/factor;   %% '*1000' is used to transfer the unit 'M' to 'nM'
plot(T/3600,NFKB,'r','linewidth',2); 
xlabel('Time (hour)','FontSize',16);
ylabel('NF-\kappaB (nM)','FontSize',16);
pause;
close; 

 



